@@ -3,7 +3,7 @@
 # HeeFramework
 # @Time    : 2020/11/10 15:06
 # @Author  : yanhu.zou
-__version__ = "1.0.28"
+__version__ = "1.0.29"
 
 import datetime
 import json
@@ -17,11 +17,11 @@ HeeFramework
 
 1. Simple to use
     Through the case in the "Instructions section" later, you will find that you will soon be able to use the framework and like it.
-   
+
 2. Lightweight and module-oriented
     Hee is lightweight, both in terms of volume and design. It manages its dependencies through the introduction of dynamic modules.
     For example, the framework provides support for MySQL but if you happen to not need MySQL, the application will not introduce any mysql-related packages at startup.
-   
+
 3. Low invasiveness
     In addition to decorators to identify the classes you need to let the container manage, almost no additional code is added.
 
@@ -42,7 +42,7 @@ HeeFramework
 
 9. Automatically check and import dependencies (TODO) before running
     When Hee starts, it will automatically scan the modules that the framework itself depends on and import them automatically. Of course, what to import depends on which features of the framework you will use.
-  
+
 
 
 """
@@ -67,11 +67,11 @@ if config.has_section('MYSQL'):
     from hee.rdb_mysql import DbMySQL
 
 
-
 class HeeContainer:
     """
     submod and object container.
     """
+
     def __init__(self):
         # all submods
         self.submods: dict = {}
@@ -89,10 +89,12 @@ class HeeContainer:
         if submod_name in self.submods:
             return self.submods[submod_name]
 
+
 class Hee:
     """
     Facade of Hee
     """
+
     def __init__(self, hee_container):
         super(Hee, self).__init__()
         self.__container = hee_container
@@ -111,6 +113,7 @@ class HeeApplication:
     Building restful applications easily
     The user needs to create a class inherited from this class and execute the start method in the main function to start the application
     """
+
     def __init__(self):
         # Hee container
         self.hee_container = HeeContainer()
@@ -167,7 +170,6 @@ class HeeApplication:
 
         self.scheduler.start()
 
-
     def start(self):
         pass
 
@@ -296,8 +298,8 @@ class HeeApplication:
                         contained_object_name = var_type.__module__ + "." + var_type.__name__
                         if contained_object_name in self.hee_container.objects:
                             setattr(submod, var_name, self.hee_container.objects[contained_object_name])
-                            log_.info("Auto inject [" + contained_object_name + "] into submod " + submod_name + " success.")
-
+                            log_.info(
+                                "Auto inject [" + contained_object_name + "] into submod " + submod_name + " success.")
 
             # 初始化所有的定时调度任务
             submod = self.hee_container.submods[submod_name]
@@ -330,7 +332,8 @@ class HeeApplication:
                                            day_of_week=day_of_week,
                                            year=year
                                            )
-                    log_.info("Job started, %s cron=%s %s %s %s %s %s %s", fun_name, seconds, minute, hour, day_of_month, month, day_of_week, year)
+                    log_.info("Job started, %s cron=%s %s %s %s %s %s %s", fun_name, seconds, minute, hour,
+                              day_of_month, month, day_of_week, year)
 
     def build_bean_dependencies(self):
         """
@@ -363,8 +366,35 @@ class HeeRestApplication(HeeApplication):
         super(HeeRestApplication, self).__init__()
         self.heeFlask = Flask(__name__, static_folder=static_path, template_folder=template_path)
         self.web = Web(self.heeFlask)
+
+        # 自动注入子模块web相关的组件
+        self.initialize_web_dependencies()
+
+        # 初始化拦截器
+        self.initialize_interceptor(self.heeFlask)
+
+        # 初始化控制器
         self.initialize_controller()
 
+    def initialize_web_dependencies(self):
+        for submod_name in self.hee_container.submods:
+            submod = self.hee_container.submods[submod_name]
+            if hasattr(submod, 'web'):
+                submod.web = self.web
+
+    def initialize_interceptor(self, heeFlask: Flask):
+        interceptors = list()
+        for submod_name in self.hee_container.submods:
+            if submod_name.endswith("interceptor"):
+                submod = self.hee_container.submods[submod_name]
+                funs = inspect.getmembers(submod, inspect.isfunction)
+                for fun_info in funs:
+                    fun = fun_info[1]  # 函数对象
+                    if hasattr(fun, '__hee_global_interceptor__'):
+                        interceptors.append(fun)
+        heeFlask.before_request_funcs[None] = interceptors
+
+    # 初始化控制器
     def initialize_controller(self):
         """
         Map all controllers
@@ -384,6 +414,7 @@ class HeeRestApplication(HeeApplication):
         log_.info("application is starting...")
         self.heeFlask.run(host=host, port=port)
 
+
 # Convert an object into a dict
 def object_to_dict(obj):
     if isinstance(obj, dict):
@@ -396,6 +427,7 @@ def object_to_dict(obj):
                 dict_data[name] = value
         return dict_data
 
+
 # Convert a dict to an object
 def dict_to_object(d: dict, t: type):
     obj = t()
@@ -472,6 +504,24 @@ class Web:
         else:
             return json.dumps(data, cls=HeeJsonEncoder)
 
+    # 获取当前访问的路径
+    def get_path(self):
+        return request.path
+
+    def get_cookie(self, name):
+        return request.cookies.get(name)
+
+    def resp_set_cookie(self, name, value):
+        resp = make_response('set_cookie')
+        resp.set_cookie('name', 'value')
+        return resp;
+
+    def resp_del_cookie(self, name):
+        resp = make_response('delete_cookie')
+        resp.delete_cookie('passwd')
+        return resp
+
+
 # Hee Json Encoder
 class HeeJsonEncoder(json.JSONEncoder):
     def default(self, obj):
@@ -481,7 +531,6 @@ class HeeJsonEncoder(json.JSONEncoder):
             return json.JSONEncoder.default(self, obj)
 
 
-
 class HeeMapping(Blueprint):
     """
     Used to declare the request path, each controller needs to create an object of this type
@@ -545,10 +594,24 @@ def heejob(job_name, cron):
     :param cron:
     :return:
     """
+
     def decorate(f):
         setattr(f, '__hee_job_enable__', True)
         setattr(f, 'job_name', job_name)
         setattr(f, 'cron', cron)
         return f
+
     return decorate
 
+
+def hee_interceptor():
+    """
+    拦截器，可以配合web.get_path对目标路径进行拦截
+    :return:
+    """
+
+    def decorate(f):
+        setattr(f, '__hee_global_interceptor__', True)
+        return f
+
+    return decorate
